@@ -330,6 +330,9 @@ class TestCase(base.BaseTestCase):
         # Reset the global key manager
         nova.crypto._KEYMGR = None
 
+        # Reset the global endpoint
+        nova.limit.utils.ENDPOINT = None
+
     def _setup_cells(self):
         """Setup a normal cellsv2 environment.
 
